# Python-accelerate
A utility package I developed for myself, to make my life as a coder/data-scientist easier.

**Dependencies:** Because this package will end up with too many dependencies, I have decided to not add them as required when setting up
the package. Instead, the user of the package should install the necessary dependencies depending on the sub-modules 
they want to use.